@@ -31,10 +31,7 @@ odeproc <- function(
                             method = method)
     } else
       if (times[1] < tshift & times[2] > tshift) {
-        #y = deSolve::ode(probs,c(times[1],tshift),fun,pars1,rtol = rtol,atol = atol,method = method)
-        y <- DAISIE_integrate(probs, c(times[1], tshift), fun, pars1, rtol = rtol, atol = atol, method = method)
-        probs <- y[2, 2:ncol(y)]
-        #y = deSolve::ode(probs,c(tshift,times[2]),fun,pars2,rtol = rtol,atol = atol,method = method)
+        probs <- DAISIE_integrate(probs, c(times[1], tshift), fun, pars1, rtol = rtol, atol = atol, method = method)
         y <- DAISIE_integrate(probs, c(tshift, times[2]), fun, pars2, rtol = rtol, atol = atol, method = method)
       }
   return(y)
@@ -46,18 +43,25 @@ divdepvecproc <- function(
   k1,
   ddep,
   times,
-  type
+  lac_or_gam
 ) {
   tshift <- -abs(pars[11])
-  if (type == "col") {
-    a <- 3
-  } else {
-    a <- 0
-  }
   if (times < tshift) {
-    return(divdepvec(pars[1 + a], pars[3], lx, k1, ddep))
+    return(divdepvec(
+      lac_or_gam = lac_or_gam,
+      pars1 = pars[1:5],
+      lx = lx,
+      k1 =  k1,
+      ddep =  ddep
+    ))
   } else {
-    return(divdepvec(pars[6 + a], pars[8], lx, k1, ddep))
+    return(divdepvec(
+      lac_or_gam = lac_or_gam,
+      pars1 = pars[6:10],
+      lx = lx,
+      k1 = k1,
+      ddep = ddep
+    ))
   }
 }
 
@@ -72,50 +76,10 @@ DAISIE_SR_loglik_CS_M1 <- DAISIE_SR_loglik <- function(
   reltolint = reltolint,
   verbose = FALSE
 ) {
-  # brts = branching times (positive, from present to past)
-  # - max(brts) = age of the island
-  # - next largest brts = stem age / time of divergence from the mainland
-  # The interpretation of this depends on stac (see below)
-  # For stac = 0, there is no other value.
-  # For stac = 1 and stac = 5, this is the time since divergence from the immigrant's sister on the mainland.
-  # The immigrant must have immigrated at some point since then.
-  # For stac = 2 and stac = 3, this is the time since divergence from the mainland.
-  # The immigrant that established the clade on the island must have immigrated precisely at this point.
-  # For stac = 3, it must have reimmigrated, but only after the first immigrant had undergone speciation.
-  # - min(brts) = most recent branching time (only for stac = 2, or stac = 3)
-  # pars1 = model parameters
-  # - pars1[1] = lac = (initial) cladogenesis rate
-  # - pars1[2] = mu = extinction rate
-  # - pars1[3] = K = maximum number of species possible in the clade
-  # - pars1[4] = gam = (initial) immigration rate
-  # - pars1[5] = laa = (initial) anagenesis rate
-  # pars2 = model settings
-  # - pars2[1] = lx = length of ODE variable x
-  # - pars2[2] = ddep = diversity-dependent model,mode of diversity-dependence
-  #  . ddep == 0 : no diversity-dependence
-  #  . ddep == 1 : linear dependence in speciation rate (anagenesis and cladogenesis)
-  #  . ddep == 11 : linear dependence in speciation rate and immigration rate
-  #  . ddep == 3 : linear dependence in extinction rate
-  # - pars2[3] = cond = conditioning
-  #  . cond == 0 : no conditioning
-  #  . cond == 1 : conditioning on presence on the island (not used in this single loglikelihood)
-  # - pars2[4] = parameters and likelihood should be printed (1) or not (0)
-  # stac = status of the clade formed by the immigrant
-  #  . stac == 0 : immigrant is not present and has not formed an extant clade
-  #  . stac == 1 : immigrant is present but has not formed an extant clade
-  #  . stac == 2 : immigrant is not present but has formed an extant clade
-  #  . stac == 3 : immigrant is present and has formed an extant clade
-  #  . stac == 4 : immigrant is present but has not formed an extant clade, and it is known when it immigrated.
-  #  . stac == 5 : immigrant is not present and has not formed an extant clade, but only an endemic species
-  # missnumspec = number of missing species
   if (is.na(pars2[4])) {
     pars2[4] <- 0
   }
   ddep <- pars2[2]
-  cond <- pars2[3]
-  if (cond > 0) {
-    cat("Conditioning has not been implemented and may not make sense. Cond is set to 0.\n")
-  }
   lac <- pars1[1]
   mu <- pars1[2]
   K <- pars1[3]
@@ -141,7 +105,7 @@ DAISIE_SR_loglik_CS_M1 <- DAISIE_SR_loglik <- function(
     loglik <- -Inf
     return(loglik)
   }
-  if (sum(brts == 0) == 0) {
+  if (!any(brts == 0)) {
     brts[length(brts) + 1] <- 0
   }
   # for stac = 0 and stac = 1, brts will contain origin of island and 0; length = 2; no. species should be 0
@@ -187,8 +151,7 @@ DAISIE_SR_loglik_CS_M1 <- DAISIE_SR_loglik <- function(
       probs <- rep(0, 2 * lx + 1)
       probs[1] <- 1
       k1 <- 0
-      y <- odeproc(probs, brts[1:2], DAISIE_loglik_rhs, c(pars1, k1, ddep), rtol = reltolint, atol = abstolint, method = methode)
-      probs <- y[2, 2:(2 * lx + 2)]
+      probs <- odeproc(probs, brts[1:2], DAISIE_loglik_rhs, c(pars1, k1, ddep), rtol = reltolint, atol = abstolint, method = methode)
       cp <- checkprobs(lv = 2 * lx, loglik, probs, verbose); loglik <- cp[[1]]; probs <- cp[[2]]
       if (stac == 0) {
       # for stac = 0, the integration is from the origin of the island until the present
@@ -204,8 +167,7 @@ DAISIE_SR_loglik_CS_M1 <- DAISIE_SR_loglik <- function(
         # but there can be missing species
         # for stac = 5, we do exactly the same, but we evaluate the probability of an endemic species being present alone.
           probs[(lx + 1):(2 * lx)] <- 0
-          y <- odeproc(probs, brts[2:3], DAISIE_loglik_rhs, c(pars1, k1, ddep), rtol = reltolint, atol = abstolint, method = methode)
-          probs <- y[2, 2:(2 * lx + 2)]
+          probs <- odeproc(probs, brts[2:3], DAISIE_loglik_rhs, c(pars1, k1, ddep), rtol = reltolint, atol = abstolint, method = methode)
           cp <- checkprobs(lv = 2 * lx, loglik, probs, verbose); loglik <- cp[[1]]; probs <- cp[[2]]
           loglik <- loglik + log(probs[(stac == 1) * lx + (stac == 5) + 1 + missnumspec])
         } else {
@@ -213,18 +175,17 @@ DAISIE_SR_loglik_CS_M1 <- DAISIE_SR_loglik <- function(
         # all probabilities of states with the immigrant present are set to zero and all probabilities of states with endemics present are transported to the state with the colonist present waiting for speciation to happen. We also multiply by the (possibly diversity-dependent) immigration rate
           if (stac == 6 || stac == 7) {
             probs[(lx + 1):(2 * lx)] <- 0
-            y <- odeproc(probs, brts[2:3], DAISIE_loglik_rhs, c(pars1, k1, ddep), rtol = reltolint, atol = abstolint, method = methode)
-            probs <- y[2, 2:(2 * lx + 2)]
+            probs <- odeproc(probs, brts[2:3], DAISIE_loglik_rhs, c(pars1, k1, ddep), rtol = reltolint, atol = abstolint, method = methode)
             cp <- checkprobs(lv = 2 * lx, loglik, probs, verbose); loglik <- cp[[1]]; probs <- cp[[2]]
             k1 <- 1
           }
           if (stac == 2 || stac == 3 || stac == 4) {
-            gamvec <- divdepvecproc(pars1, lx, k1, ddep * (ddep == 11 | ddep == 21), brts[2], "col")
-            probs[(2 * lx + 1):(3 * lx)] <- gamvec[1:lx] * probs[1:lx]
+            gamvec <- divdepvecproc(pars1, lx, k1, ddep * (ddep == 11 | ddep == 21), brts[2], "gam")
+            probs[(2 * lx + 1):(3 * lx)] <- gamvec[1:lx] * probs[1:lx] +
+              gamvec[2:(lx + 1)] * probs[(lx + 1):(2 * lx)]
             probs[1:(2 * lx)] <- 0
             k1 <- 1
-            y <- odeproc(probs, brts[2:3], DAISIE_loglik_rhs2, c(pars1, k1, ddep), rtol = reltolint, atol = abstolint, method = methode)
-            probs <- y[2, 2:(3 * lx + 1)]
+            probs <- odeproc(probs, brts[2:3], DAISIE_loglik_rhs2, c(pars1, k1, ddep), rtol = reltolint, atol = abstolint, method = methode)
             cp <- checkprobs2(lx, loglik, probs, verbose); loglik <- cp[[1]]; probs <- cp[[2]]
           }
           if (stac == 4) {
@@ -235,7 +196,7 @@ DAISIE_SR_loglik_CS_M1 <- DAISIE_SR_loglik <- function(
             S1 <- length(brts) - 1
             startk <- 3
             if (S1 >= startk) {
-              lacvec <- divdepvecproc(pars1, lx, k1, ddep, brts[3], "spec")
+              lacvec <- divdepvecproc(pars1, lx, k1, ddep, brts[3], "lac")
               if (stac == 2 || stac == 3) {
                 probs[1:lx] <- lacvec[1:lx] * (probs[1:lx] + probs[(2 * lx + 1):(3 * lx)])
                 probs[(lx + 1):(2 * lx)] <- lacvec[2:(lx + 1)] * probs[(lx + 1):(2 * lx)]
@@ -254,12 +215,11 @@ DAISIE_SR_loglik_CS_M1 <- DAISIE_SR_loglik <- function(
               }
               for (k in startk:S1) {
                 k1 <- k - 1
-                y <- odeproc(probs, brts[k:(k + 1)], DAISIE_loglik_rhs, c(pars1, k1, ddep), rtol = reltolint, atol = abstolint, method = methode)
-                probs <- y[2, 2:(2 * lx + 2)]
+                probs <- odeproc(probs = probs, times = brts[k:(k + 1)], fun = DAISIE_loglik_rhs, pars = c(pars1, k1, ddep), rtol = reltolint, atol = abstolint, method = methode)
                 cp <- checkprobs2(lx, loglik, probs, verbose); loglik <- cp[[1]]; probs <- cp[[2]]
                 if (k < S1) {
                   # speciation event
-                  lacvec <- divdepvecproc(pars1, lx, k1, ddep, brts[k + 1], "spec")
+                  lacvec <- divdepvecproc(pars1, lx, k1, ddep, brts[k + 1], "lac")
                   probs[1:(2 * lx)] <- c(lacvec[1:lx], lacvec[2:(lx + 1)]) * probs[1:(2 * lx)]
                 }
               }
@@ -297,60 +257,81 @@ DAISIE_SR_loglik_CS_M1 <- DAISIE_SR_loglik <- function(
 #'
 #' @aliases DAISIE_SR_loglik_CS DAISIE_SR_loglik_all
 #'
-#' @param pars1 Contains the model parameters: \cr \cr \code{pars1[1]}
-#' corresponds to lambda^c (cladogenesis rate) \cr \code{pars1[2]} corresponds
-#' to mu (extinction rate) \cr \code{pars1[3]} corresponds to K (clade-level
-#' carrying capacity) \cr \code{pars1[4]} corresponds to gamma (immigration
-#' rate) \cr \code{pars1[5]} corresponds to lambda^a (anagenesis rate) \cr
+#' @inheritParams default_params_doc
+#' @param pars1 Contains the model parameters: \cr \cr
+#' \code{pars1[1]}
+#' corresponds to lambda^c (cladogenesis rate) \cr
+#' \code{pars1[2]} corresponds
+#' to mu (extinction rate) \cr
+#' \code{pars1[3]} corresponds to K (clade-level
+#' carrying capacity) \cr
+#' \code{pars1[4]} corresponds to gamma (immigration
+#' rate) \cr
+#' \code{pars1[5]} corresponds to lambda^a (anagenesis rate) \cr
 #' \code{pars1[6]} corresponds to lambda^c (cladogenesis rate) after the shift
-#' \cr \code{pars1[7]} corresponds to mu (extinction rate) after the shift \cr
+#' \cr
+#' \code{pars1[7]} corresponds to mu (extinction rate) after the shift \cr
 #' \code{pars1[8]} corresponds to K (clade-level carrying capacity) after the
-#' shift \cr \code{pars1[9]} corresponds to gamma (immigration rate) after the
-#' shift \cr \code{pars1[10]} corresponds to lambda^a (anagenesis rate) after
-#' the shift \cr \code{pars1[11]} corresponds to the time of shift \cr
-#' @param pars2 Contains the model settings \cr \cr \code{pars2[1]} corresponds
-#' to lx = length of ODE variable x \cr \code{pars2[2]} corresponds to ddmodel
-#' = diversity-dependent model, model of diversity-dependence, which can be one
-#' of\cr \cr ddmodel = 0 : no diversity dependence \cr ddmodel = 1 : linear
-#' dependence in speciation rate \cr ddmodel = 11: linear dependence in
-#' speciation rate and in immigration rate \cr ddmodel = 2 : exponential
-#' dependence in speciation rate\cr ddmodel = 21: exponential dependence in
-#' speciation rate and in immigration rate\cr \cr \code{pars2[3]} corresponds
-#' to cond = setting of conditioning\cr \cr cond = 0 : conditioning on island
-#' age \cr cond = 1 : conditioning on island age and non-extinction of the
-#' island biota \cr \cr \code{pars2[4]} sets whether parameters and likelihood
-#' should be printed (1) or not (0)
+#' shift \cr
+#' \code{pars1[9]} corresponds to gamma (immigration rate) after the
+#' shift \cr
+#' \code{pars1[10]} corresponds to lambda^a (anagenesis rate) after
+#' the shift \cr
+#' \code{pars1[11]} corresponds to the time of shift \cr
+#' @param pars2 Contains the model settings \cr \cr
+#' \code{pars2[1]} corresponds
+#' to lx = length of ODE variable x \cr
+#' \code{pars2[2]} corresponds to ddmodel = diversity-dependent model,
+#' model of diversity-dependence, which can be one of\cr \cr
+#' ddmodel = 0 : no diversity dependence \cr
+#' ddmodel = 1 : linear dependence in speciation rate \cr
+#' ddmodel = 11: linear dependence in speciation rate and in immigration rate \cr
+#' ddmodel = 2 : exponential dependence in speciation rate\cr
+#' ddmodel = 21: exponential dependence in speciation rate and in immigration rate\cr \cr
+#' \code{pars2[3]} corresponds
+#' to cond = setting of conditioning\cr \cr
+#' cond = 0 : conditioning on island age \cr
+#' cond = 1 : conditioning on island age and non-extinction of the
+#' island biota \cr
+#' cond > 1 : conditioning on island age and having at least cond colonizations on the island \cr \cr
+#' \code{pars2[4]} sets whether parameters and likelihood should be printed (1) or not (0)
 #' @param datalist Data object containing information on colonisation and
 #' branching times. This object can be generated using the DAISIE_dataprep
 #' function, which converts a user-specified data table into a data object, but
 #' the object can of course also be entered directly. It is an R list object
-#' with the following elements.\cr The first element of the list has two or
-#' three components: \cr \cr \code{$island_age} - the island age \cr Then,
-#' depending on whether a distinction between types is made, we have:\cr
+#' with the following elements.\cr
+#' The first element of the list has two or three components: \cr \cr
+#' \code{$island_age} - the island age \cr
+#' Then, depending on whether a distinction between types is made, we have:\cr
 #' \code{$not_present} - the number of mainland lineages that are not present
-#' on the island \cr The remaining elements of the list each contains
+#' on the island \cr
+#' The remaining elements of the list each contains
 #' information on a single colonist lineage on the island and has 5
-#' components:\cr \cr \code{$colonist_name} - the name of the species or clade
-#' that colonized the island \cr \code{$branching_times} - island age and stem
+#' components:\cr \cr
+#' \code{$colonist_name} - the name of the species or clade
+#' that colonized the island \cr
+#' \code{$branching_times} - island age and stem
 #' age of the population/species in the case of Non-endemic, Non-endemic_MaxAge
 #' and Endemic anagenetic species. For cladogenetic species these should be
 #' island age and branching times of the radiation including the stem age of
-#' the radiation.\cr \code{$stac} - the status of the colonist \cr \cr *
-#' Non_endemic_MaxAge: 1 \cr * Endemic: 2 \cr * Endemic&Non_Endemic: 3 \cr *
-#' Non_endemic: 4 \cr * Endemic_MaxAge: 5 \cr \cr \code{$missing_species} -
+#' the radiation.\cr
+#' \code{$stac} - the status of the colonist \cr \cr
+#' - Non_endemic_MaxAge: 1 \cr * Endemic: 2 \cr
+#' - Endemic&Non_Endemic: 3 \cr
+#' - Non_endemic: 4 \cr
+#' - Endemic_MaxAge: 5 \cr \cr
+#' \code{$missing_species} -
 #' number of island species that were not sampled for particular clade (only
 #' applicable for endemic clades) \cr
 #' @param methode Method of the ODE-solver. See package deSolve for details.
 #' Default is "lsodes"
-#' @param CS_version For internal testing purposes only. Default is 1, the
-#' original DAISIE code.
 #' @param abstolint Absolute tolerance of the integration
 #' @param verbose Logical controling if progress is printed to console.
 #' @param reltolint Relative tolerance of the integration
 #'
 #' @return The loglikelihood
 #' @author Rampal S. Etienne & Bart Haegeman
-#' @seealso \code{\link{DAISIE_ML}}, \code{\link{DAISIE_sim_constant_rate}}
+#' @seealso \code{\link{DAISIE_ML}}, \code{\link{DAISIE_sim_cr}}
 #' @references Valente, L.M., A.B. Phillimore and R.S. Etienne (2015).
 #' Equilibrium and non-equilibrium dynamics simultaneously operate in the
 #' Galapagos islands. Ecology Letters 18: 844-852.
@@ -375,47 +356,6 @@ DAISIE_SR_loglik_CS <- DAISIE_SR_loglik_all <- function(
   reltolint = 1E-10,
   verbose = FALSE
 ) {
-  # datalist = list of all data: branching times, status of clade, and numnber of missing species
-  # datalist[[,]][1] = list of branching times (positive, from present to past)
-  # - max(brts) = age of the island
-  # - next largest brts = stem age / time of divergence from the mainland
-  # The interpretation of this depends on stac (see below)
-  # For stac = 0, this needs to be specified only once.
-  # For stac = 1, this is the time since divergence from the immigrant's sister on the mainland.
-  # The immigrant must have immigrated at some point since then.
-  # For stac = 2 and stac = 3, this is the time since divergence from the mainland.
-  # The immigrant that established the clade on the island must have immigrated precisely at this point.
-  # For stac = 3, it must have reimmigrated, but only after the first immigrant had undergone speciation.
-  # - min(brts) = most recent branching time (only for stac = 2, or stac = 3)
-  # datalist[[,]][2] = list of status of the clades formed by the immigrant
-  #  . stac == 0 : immigrant is not present and has not formed an extant clade
-  # Instead of a list of zeros, here a number must be given with the number of clades having stac = 0
-  #  . stac == 1 : immigrant is present but has not formed an extant clade
-  #  . stac == 2 : immigrant is not present but has formed an extant clade
-  #  . stac == 3 : immigrant is present and has formed an extant clade
-  #  . stac == 4 : immigrant is present but has not formed an extant clade, and it is known when it immigrated.
-  #  . stac == 5 : immigrant is not present and has not formed an extant clade, but only an endemic species
-  # datalist[[,]][3] = list with number of missing species in clades for stac = 2 and stac = 3;
-  # for stac = 0 and stac = 1, this number equals 0.
-  # pars1 = model parameters
-  # - pars1[1] = lac = (initial) cladogenesis rate
-  # - pars1[2] = mu = extinction rate
-  # - pars1[3] = K = maximum number of species possible in the clade
-  # - pars1[4] = gam = (initial) immigration rate
-  # - pars1[5] = laa = (initial) anagenesis rate
-  # - pars1[6]...pars1[10] = same as pars1[1]...pars1[5], but after the shift
-  # - pars1[11] = time of shift
-  # pars2 = model settings
-  # - pars2[1] = lx = length of ODE variable x
-  # - pars2[2] = ddep = diversity-dependent model,mode of diversity-dependence
-  #  . ddep == 0 : no diversity-dependence
-  #  . ddep == 1 : linear dependence in speciation rate (anagenesis and cladogenesis)
-  #  . ddep == 11 : linear dependence in speciation rate and immigration rate
-  #  . ddep == 3 : linear dependence in extinction rate
-  # - pars2[3] = cond = conditioning
-  #  . cond == 0 : no conditioning
-  #  . cond == 1 : conditioning on presence on the island (not used in this single loglikelihood)
-  # - pars2[4] = parameters and likelihood should be printed (1) or not (0)
   pars1 = as.numeric(pars1)
   check_shift_loglik = shift_before_certain_brts(datalist, pars1)
   if(check_shift_loglik != 0){
@@ -440,7 +380,7 @@ DAISIE_SR_loglik_CS <- DAISIE_SR_loglik_all <- function(
   }
   loglik <- not_present * logp0
   numimm <- not_present + length(datalist) - 1
-  logcond <- (cond == 1) * log(1 - exp(numimm * logp0))
+  logcond <- logcondprob(numcolmin = cond,numimm = numimm,logp0 = logp0)
   loglik <- loglik - logcond
   if (length(datalist) > 1) {
     for (i in 2:length(datalist)) {
