@@ -9,7 +9,7 @@
 #'
 #' @examples
 #' island_replicates <- list()
-#' island_replicates[[1]] <- DAISIE:::DAISIE_sim_core_constant_rate(
+#' island_replicates[[1]] <- DAISIE:::DAISIE_sim_core_cr(
 #'   time = 5,
 #'   mainland_n = 1000,
 #'   pars = c(2, 2, 40, 0.1, 1),
@@ -24,17 +24,24 @@
 #'   hyper_pars = create_hyper_pars(d = 0.2, x = 0.1),
 #'   nonoceanic_pars = c(0, 0)
 #')
-#' formated_island <- DAISIE:::DAISIE_format_IW(
+#' formatted_island_sampled <- DAISIE:::DAISIE_format_IW(
 #'   island_replicates = island_replicates,
 #'   time = 5,
 #'   M = 1000,
 #'   sample_freq = 25,
 #'   verbose = FALSE
 #')
+#' formatted_island_full <- DAISIE:::DAISIE_format_IW(
+#'   island_replicates = island_replicates,
+#'   time = 5,
+#'   M = 1000,
+#'   sample_freq = Inf,
+#'   verbose = FALSE
+#')
 DAISIE_format_IW <- function(island_replicates,
                              time,
                              M,
-                             sample_freq,
+                             sample_freq = 25,
                              verbose = TRUE,
                              trait_pars = NULL) {
 
@@ -50,56 +57,31 @@ DAISIE_format_IW <- function(island_replicates,
       )
     )
   }
-  totaltime <- time
-  several_islands <- list()
-  for (rep in 1:length(island_replicates)) {
-    the_island <- island_replicates[[rep]]
-    stt_all <- matrix(ncol = 4, nrow = sample_freq + 1)
-    colnames(stt_all) <- c("Time", "nI", "nA", "nC")
-    stt_all[, "Time"] <- rev(seq(from = 0,
-                                 to = totaltime,
-                                 length.out = sample_freq + 1))
-    immig_spec <- the_island$stt_table[1, 2]
-    ana_spec <- the_island$stt_table[1, 3]
-    stt_all[1, 2:4] <- c(immig_spec,
-                         ana_spec,
-                         0)
-    the_stt <- the_island$stt_table
-    for (i in 2:nrow(stt_all)) {
-      the_age <- stt_all[i, "Time"]
-      stt_all[i, 2:4] <- the_stt[max(which(the_stt[, "Time"] >= the_age)), 2:4]
-    }
-    island_list <- list()
-    if (sum(the_stt[nrow(the_stt), 2:4]) == 0) {
-      island_list[[1]] <- list(
-        island_age = totaltime,
-        not_present = M,
-        stt_all = stt_all
-      )
-    } else {
-      island_list[[1]] <- list(
-        island_age = totaltime,
-        not_present = M - length(the_island$taxon_list),
-        stt_all = stt_all
-      )
-      for (y in 1:length(the_island$taxon_list)) {
-        island_list[[y + 1]] <- the_island$taxon_list[[y]]
-      }
-    }
-    island_list <- Add_brt_table(island_list)
-    several_islands[[rep]] <- island_list
 
-    if (verbose == TRUE) {
-      print(paste(
-        "Island being formatted: ",
-        rep,
-        "/",
-        length(island_replicates),
-        sep = "")
-      )
-    }
+  total_time <- time
+  testit::assert(
+    !is.na(sample_freq) && !is.null(sample_freq) && sample_freq >= 1
+  )
+
+  if (is.infinite(sample_freq)) {
+    several_islands <- DAISIE_format_IW_full_stt(
+      island_replicates,
+      total_time = total_time,
+      M = M,
+      verbose = verbose
+    )
+  } else {
+    several_islands <- DAISIE_format_IW_sampled_stt(
+      island_replicates = island_replicates,
+      total_time = total_time,
+      M = M,
+      sample_freq = sample_freq,
+      verbose = verbose
+    )
   }
+
   return(several_islands)
+
 }
 
 DAISIE_format_IW_trait <- function(island_replicates,
@@ -110,7 +92,7 @@ DAISIE_format_IW_trait <- function(island_replicates,
                                    trait_pars = NULL)
 {
 
-  totaltime <- time
+  total_time <- time
   several_islands = list()
   for(rep in 1:length(island_replicates))
   {
@@ -120,8 +102,10 @@ DAISIE_format_IW_trait <- function(island_replicates,
     Mtotal <- M1 + M2
     stt_all = matrix(ncol = 7,nrow = sample_freq + 1)
     colnames(stt_all) = c("Time","nI","nA","nC","nI2","nA2","nC2")
-    stt_all[,"Time"] = rev(seq(from = 0,to = totaltime,length.out = sample_freq + 1))
-    stt_all[1,2:7] = c(0,0,0,0,0,0)
+
+    stt_all[,"Time"] = rev(seq(from = 0,to = total_time, length.out = sample_freq + 1))
+    stt_all[1, 2:7] = c(0, 0, 0, 0, 0, 0)
+
 
     the_stt = the_island$stt_table
 
@@ -136,14 +120,14 @@ DAISIE_format_IW_trait <- function(island_replicates,
     {
 
       island_list[[1]] = list(
-        island_age = totaltime,
+        island_age = total_time,
         not_present = Mtotal,
         stt_all = stt_all
       )
 
     } else {
 
-      island_list[[1]] = list(island_age = totaltime,
+      island_list[[1]] = list(island_age = total_time,
                               not_present = Mtotal - length(the_island$taxon_list),
                               stt_all = stt_all)
 
@@ -153,28 +137,24 @@ DAISIE_format_IW_trait <- function(island_replicates,
       }
     }
 
-    island_list = Add_brt_table(island_list)
+    island_list <- add_brt_table(island_list)
 
     several_islands[[rep]] = island_list
-    if (verbose) {
-      print(paste(
-        "Island being formatted: ",
-        rep,
-        "/",
-        length(island_replicates),
-        sep = "")
+    if (verbose == TRUE) {
+      message(
+        "Island being formatted: ", rep, "/", length(island_replicates)
       )
     }
   }
   return(several_islands)
 }
 
-Add_brt_table <- function(island) {
+add_brt_table <- function(island, full_table = FALSE) {
   island_age <- island[[1]]$island_age
   island_top <- island[[1]]
   if (length(island) == 1) {
-    brts_table <- matrix(ncol = 4, nrow = 1)
-    brts_table[1, ] <-  c(island_age, 0, 0, NA)
+    brts_table <- matrix(ncol = 5, nrow = 1)
+    brts_table[1, ] <-  c(island_age, 0, 0, NA, NA)
     island[[1]]$brts_table <- brts_table
   } else {
     island_top <- island[[1]]
@@ -190,8 +170,8 @@ Add_brt_table <- function(island) {
     stac1_5s <- sort(c(stac1s, stac5s))
     if (length(stac1_5s) != 0) {
       if (length(stac1_5s) == length(island)) {
-        brts_table <- matrix(ncol = 4, nrow = 1)
-        brts_table[1, ] <- c(island_age, 0, 0, NA)
+        brts_table <- matrix(ncol = 5, nrow = 1)
+        brts_table[1, ] <- c(island_age, 0, 0, NA, NA)
         island_no_stac1or5 <- NULL
       } else {
         island_no_stac1or5 <- island[-stac1_5s]
@@ -206,21 +186,41 @@ Add_brt_table <- function(island) {
         btimes[[i]] <- island_no_stac1or5[[i]]$branching_times[-1]
       }
       brts <- rev(sort(unlist(btimes)))
-      brts_IWK <- matrix(ncol = 4, nrow = length(brts))
+      brts_IWK <- NULL
       pos1 <- 0
+      j <- 1
       for (i in 1:length(btimes)) {
         the_brts <- btimes[[i]]
         the_stac <- island_no_stac1or5[[i]]$stac
         pos2 <- pos1 + length(the_brts)
-        brts_IWK[(pos1 + 1):pos2, 1] <- the_brts
-        brts_IWK[(pos1 + 1):pos2, 2] <- i
-        brts_IWK[(pos1 + 1):pos2, 3] <- seq(1, length(the_brts))
-        brts_IWK[(pos1 + 1):pos2, 4] <- (the_stac == 2) +
+        ff <- matrix(ncol = 5, nrow = pos2 - pos1)
+        ff[1:(pos2 - pos1), 1] <- the_brts
+        ff[1:(pos2 - pos1), 2] <- i
+        ff[1:(pos2 - pos1), 3] <- seq(1, length(the_brts))
+        ff[1:(pos2 - pos1), 4] <- (the_stac == 2) +
           (the_stac == 3) + (the_stac == 4) * 0
+        ff[1:(pos2 - pos1), 5] <- NA
+        brts_IWK <- rbind(brts_IWK,ff)
         pos1 <- pos2
+        j <- j + 1
+        if( !is.null(island[[i]]$all_colonisations) & full_table == TRUE) {
+          for (k in 1:length(island[[i]]$all_colonisations)) {
+            the_brts <- island[[i]]$all_colonisations[[k]]$event_times[-1]
+            pos2 <- pos1 + length(the_brts)
+            ff <- matrix(ncol = 5, nrow = pos2 - pos1 + 1)
+            ff[1:(pos2 - pos1), 1] <- the_brts
+            ff[1:(pos2 - pos1), 2] <- j
+            ff[1:(pos2 - pos1), 3] <- seq(1, length(the_brts))
+            ff[1:(pos2 - pos1), 4] <- NA
+            ff[1:(pos2 - pos1), 5] <- j - 1
+            brts_IWK <- rbind(brts_IWK,ff)
+            pos1 <- pos2
+            j <- j + 1
+          }
+        }
       }
       brts_table <- brts_IWK[rev(order(brts_IWK[, 1])), ]
-      brts_table <- rbind(c(island_age, 0, 0, NA), brts_table)
+      brts_table <- rbind(c(island_age, 0, 0, NA, NA), brts_table)
     }
     island_top$brts_table <- brts_table
     if (length(stac1_5s) != 0) {
@@ -232,6 +232,6 @@ Add_brt_table <- function(island) {
     }
     island <- append(list(island_top), island)
   }
-  colnames(island[[1]]$brts_table) <- c("brt", "clade", "event", "endemic")
+  colnames(island[[1]]$brts_table) <- c("brt", "clade", "event", "endemic", "col")
   return(island)
 }
