@@ -98,15 +98,17 @@
 #'     cladogenesis rate}
 #'     \item{[2]: is x the exponent for calculating extinction rate}
 #'   }
-#' @param island_ontogeny In \code{\link{DAISIE_sim_time_dependent}()},
+#' @param island_ontogeny In \code{\link{DAISIE_sim_time_dep}()},
 #'   \code{\link{DAISIE_ML_CS}} and plotting a string describing the type of
 #'   island ontogeny. Can be \code{"const"}, \code{"beta"} for a beta function
 #'   describing area through time. String checked by
 #'   \code{\link{is_island_ontogeny_input}()}. \cr In all other functions a
 #'   numeric describing the type of island ontogeny. Can be \code{0} for
 #'   constant, \code{1} for a beta function describing area through time. In ML
-#'   functions \code{island_ontogeny = NA} assumes constant ontogeny.
-#' @param sea_level In \code{\link{DAISIE_sim_time_dependent}()} and plotting a
+#'   functions \code{island_ontogeny = NA} assumes constant ontogeny. Time
+#'   dependent estimation is not yet available as development is still ongoing.
+#'   Will return an error if called in that case.
+#' @param sea_level In \code{\link{DAISIE_sim_time_dep}()} and plotting a
 #'   string describing the type of sea level. Can be \code{"const"} or
 #'   \code{"sine"} for a sine function describing area through time. String
 #'   checked by \code{\link{is_sea_level_input}()}.
@@ -123,9 +125,9 @@
 #'   If using an island-wide diversity dependence, this value is set to the
 #'   number of mainland species.
 #' @param island_replicates List output from
-#'   \code{\link{DAISIE_sim_core_constant_rate}()},
-#'   \code{\link{DAISIE_sim_core_time_dependent}()},
-#'   \code{\link{DAISIE_sim_core_constant_rate_shift}()} or
+#'   \code{\link{DAISIE_sim_core_cr}()},
+#'   \code{\link{DAISIE_sim_core_time_dep}()},
+#'   \code{\link{DAISIE_sim_core_cr_shift}()} or
 #'   \code{\link{DAISIE_sim_min_type2}()} functions. Minimally, this must be a
 #'   list that has as many elements as replicates. Each element must be a list
 #'   with the elements \code{island_age}, \code{not_present} and \code{stt_all}.
@@ -139,7 +141,8 @@
 #' @param max_rates named list of numeric max rates as returned by
 #'   \code{\link{update_max_rates}()}.
 #' @param timeval Numeric defining current time of simulation.
-#' @param totaltime Numeric defining the length of the simulation in time units.
+#' @param total_time Numeric defining the length of the simulation in time
+#'   units.
 #' @param possible_event Numeric defining what event will happen.
 #' @param maxspecID Current species IDs.
 #' @param mainland_spec Number of mainland species.
@@ -239,6 +242,8 @@
 #'   immigration rate\cr
 #' @param cond cond = 0 : conditioning on island age \cr cond = 1 :
 #'   conditioning on island age and non-extinction of the island biota \cr.
+#'   cond > 1 : conditioning on island age and having at least cond colonizations
+#'   on the island. This last option is not yet available for the IW model \cr
 #' @param eqmodel Sets the equilibrium constraint that can be used during the
 #'   likelihood optimization. Only available for datatype = 'single'.\cr\cr
 #'   eqmodel = 0 : no equilibrium is assumed \cr eqmodel = 13 : near-equilibrium
@@ -259,15 +264,24 @@
 #'   relative tolerance of function value in optimization \cr abstolx = absolute
 #'   tolerance of parameter values in optimization.
 #' @param maxiter Sets the maximum number of iterations in the optimization.
-#' @param methode Method of the ODE-solver. See package deSolve for details.
-#'   Default is "lsodes".
+#' @param methode Method of the ODE-solver. Supported Boost \code{ODEINT}
+#'   solvers (steppers) are:
+#'   \code{"odeint::runge_kutta_cash_karp54"}
+#'   \code{"odeint::runge_kutta_fehlberg78"}
+#'   \code{"odeint::runge_kutta_dopri5"}
+#'   \code{"odeint::bulirsch_stoer"}
+#'   without \code{odeint::}-prefix, \code{\link{deSolve}{ode}} method is
+#'   assumed. The default method overall is
+#'   \code{"lsodes"} for \code{\link{DAISIE_ML_CS}()}
+#'   and \code{"ode45"} from \code{\link[deSolve]{ode}()} for
+#'   \code{\link{DAISIE_ML_IW}()}.
 #' @param optimmethod Method used in likelihood optimization. Default is
-#'   "subplex" (see subplex package). Alternative is 'simplex' which was the
-#'   method in previous versions.
+#'   `subplex` (see `\link[subplex]{subplex}()` for full details).
+#'   Alternative is \code{"simplex"} which was the method in previous versions.
 #' @param tolint Vector of two elements containing the absolute and relative
 #'   tolerance of the integration.
 #' @param datatable Data frame (table) with user-specified data. See file
-#'   Galapagos_datatable.Rdata for a template of an input table. Each row on the
+#'   \code{Galapagos_datatable} for a template of an input table. Each row on the
 #'   table represents and independent colonisation event. Table has the
 #'   following four columns. \cr \cr \code{$Clade_name} - name of independent
 #'   colonization event \cr \code{$Status} - One of the following categories:
@@ -331,7 +345,7 @@
 #' @param num_immigrants A numeric with the current number of non-endemic
 #' species (a.k.a non-endemic species).
 #' @param global_min_area_time stub
-#' @param global_max_area_time  stub
+#' @param global_max_area_time stub
 #' @param distance_type Use 'continent' if the distance to the continent should
 #'   be used, use 'nearest_big' if the distance to the nearest big landmass
 #'   should be used, and use 'biologically_realistic' if the distance should
@@ -401,10 +415,12 @@
 #'   at the end of the simulation).
 #' @param jitter Numeric for \code{\link[DDD]{optimizer}()}. Jitters the
 #'   parameters being optimized by the specified amount which should be very
-#'   small, e.g. 1e-5. Jitter when \code{link[subplex]{subplex}()} produces
+#'   small, e.g. 1e-5. Jitter when \code{link{subplex}{subplex}()} produces
 #'   incorrect output due to parameter transformation.
+#' @param num_cycles The number of cycles the optimizer will go through.
+#'   Default is 1.
 #' @param trait_pars A named list containing diversification rates considering
-#' two trait states created by \code{\link{create_trait_pars}}:
+#'   two trait states created by \code{\link{create_trait_pars}}:
 #' \itemize{
 #'   \item{[1]:A numeric with the per capita transition rate with state1}
 #'   \item{[2]:A numeric with the per capita immigration rate with state2}
@@ -429,10 +445,10 @@
 #' \itemize{
 #'   \item{model: the CS model to run, options are \code{1} for single rate
 #'   DAISIE model, \code{2} for multi-rate DAISIE, or \code{0} for IW test
-#'   model}
+#'   model.}
 #'   \item{relaxed_par: the parameter to relax (integrate over). Options are
 #' \code{"cladogenesis"}, \code{"extinction"}, \code{"carrying_capacity"},
-#' \code{"immigration"}, or \code{"anagenesis"}}
+#' \code{"immigration"}, or \code{"anagenesis"}.}
 #'   }
 #' @param DAISIE_par A numeric parameter to evaluate the integral of the
 #' function.
@@ -448,6 +464,12 @@
 #' @note This is an internal function, so it should be marked with
 #'   \code{@noRd}. This is not done, as this will disallow all
 #'   functions to find the documentation parameters
+#' @param clado_rate Numeric rate of cladogenesis
+#' @param ext_rate Numeric rate of extinction
+#' @param carr_cap Numeric carrying capacity
+#' @param immig_rate Numeric rate of immigration
+#' @param ana_rate Numeric rate of anagenesis
+#'
 #'
 #' @return Nothing
 default_params_doc <- function(
@@ -476,7 +498,7 @@ default_params_doc <- function(
   rates,
   max_rates,
   timeval,
-  totaltime,
+  total_time,
   possible_event,
   maxspecID,
   mainland_spec,
@@ -559,6 +581,7 @@ default_params_doc <- function(
   proptime_max,
   current_area,
   jitter,
+  num_cycles,
   trait_pars,
   relaxed_par,
   relaxed_rate_pars,
@@ -571,7 +594,12 @@ default_params_doc <- function(
   reltolint,
   pick,
   mean,
-  sd
+  sd,
+  clado_rate,
+  ext_rate,
+  carr_cap,
+  immig_rate,
+  ana_rate
 ) {
   # Nothing
 }
