@@ -1,5 +1,3 @@
-context("DAISIE_format_IW")
-
 test_that("silent with empty island with correct output", {
   pars <- c(0.4, 0.2, 10, 0.0001, 0.5)
   time <- 1
@@ -19,7 +17,7 @@ test_that("silent with empty island with correct output", {
 
   set.seed(1)
   island_replicates <- list()
-  island_replicates[[1]] <- DAISIE:::DAISIE_sim_core_constant_rate(
+  island_replicates[[1]] <- DAISIE:::DAISIE_sim_core_cr(
     time = time,
     pars = pars,
     mainland_n = mainland_n,
@@ -28,7 +26,7 @@ test_that("silent with empty island with correct output", {
     nonoceanic_pars = nonoceanic_pars
   )
   expect_silent(
-    formated_IW_sim <- DAISIE:::DAISIE_format_IW(
+    formatted_IW_sim <- DAISIE:::DAISIE_format_IW(
       island_replicates = island_replicates,
       time = time,
       M = mainland_n,
@@ -42,14 +40,14 @@ test_that("silent with empty island with correct output", {
   colnames(stt_all) <- c("Time", "nI", "nA", "nC")
   stt_all[1, ] <- c(1, 0, 0, 0)
   stt_all[2, ] <- c(0, 0, 0, 0)
-  brts_table <- matrix(ncol = 4, nrow = 1)
-  colnames(brts_table) <- c("brt", "clade", "event", "endemic")
-  brts_table[1, ] <- c(1, 0, 0, NA)
+  brts_table <- matrix(ncol = 5, nrow = 1)
+  colnames(brts_table) <- c("brt", "clade", "event", "endemic", "col")
+  brts_table[1, ] <- c(1, 0, 0, NA, NA)
   expected_IW_format[[1]][[1]] <- list(island_age = 1,
                                        not_present = 10,
                                        stt_all = stt_all,
                                        brts_table = brts_table)
-  expect_true(all.equal(formated_IW_sim, expected_IW_format, tolerance = 1e-7))
+  expect_equal(formatted_IW_sim, expected_IW_format, tolerance = 1e-7)
 })
 
 test_that("silent with non-empty island with correct output", {
@@ -70,7 +68,7 @@ test_that("silent with non-empty island with correct output", {
   nonoceanic_pars <- c(0, 0)
   set.seed(1)
   island_replicates <- list()
-  island_replicates[[1]] <- DAISIE:::DAISIE_sim_core_constant_rate(
+  island_replicates[[1]] <- DAISIE:::DAISIE_sim_core_cr(
     time = time,
     pars = pars,
     mainland_n = mainland_n,
@@ -79,7 +77,7 @@ test_that("silent with non-empty island with correct output", {
     nonoceanic_pars = nonoceanic_pars
   )
   expect_silent(
-    formated_IW_sim <- DAISIE:::DAISIE_format_IW(
+    formatted_IW_sim <- DAISIE:::DAISIE_format_IW(
       island_replicates = island_replicates,
       time = time,
       M = mainland_n,
@@ -93,14 +91,14 @@ test_that("silent with non-empty island with correct output", {
   colnames(stt_all) <- c("Time", "nI", "nA", "nC")
   stt_all[1, ] <- c(1, 0, 0, 0)
   stt_all[2, ] <- c(0, 2, 0, 3)
-  brts_table <- matrix(ncol = 4, nrow = 6)
-  colnames(brts_table) <- c("brt", "clade", "event", "endemic")
-  brts_table[1, ] <- c(1, 0, 0, NA)
-  brts_table[2, ] <- c(0.9244818166871660, 1, 1, 1)
-  brts_table[3, ] <- c(0.9105856673960619, 1, 2, 1)
-  brts_table[4, ] <- c(0.5557734125062590, 2, 1, 0)
-  brts_table[5, ] <- c(0.5288428248966160, 3, 1, 0)
-  brts_table[6, ] <- c(0.3146835586399670, 1, 3, 1)
+  brts_table <- matrix(ncol = 5, nrow = 6)
+  colnames(brts_table) <- c("brt", "clade", "event", "endemic", "col")
+  brts_table[1, ] <- c(1, 0, 0, NA, NA)
+  brts_table[2, ] <- c(0.9244818166871660, 1, 1, 1, NA)
+  brts_table[3, ] <- c(0.9105856673960619, 1, 2, 1, NA)
+  brts_table[4, ] <- c(0.5557734125062590, 2, 1, 0, NA)
+  brts_table[5, ] <- c(0.5288428248966160, 3, 1, 0, NA)
+  brts_table[6, ] <- c(0.3146835586399670, 1, 3, 1, NA)
   expected_IW_format[[1]][[1]] <- list(island_age = 1,
                                        not_present = 7,
                                        stt_all = stt_all,
@@ -119,7 +117,7 @@ test_that("silent with non-empty island with correct output", {
                                                            0.5288428248966160),
                                        stac = 4,
                                        missing_species = 0)
-  expect_true(all.equal(formated_IW_sim, expected_IW_format, tolerance = 1e-7))
+  expect_equal(formatted_IW_sim, expected_IW_format, tolerance = 1e-7)
 })
 
 test_that("DAISIE_format_IW prints when verbose = TRUE", {
@@ -140,7 +138,7 @@ test_that("DAISIE_format_IW prints when verbose = TRUE", {
   nonoceanic_pars <- c(0, 0)
   set.seed(1)
   island_replicates <- list()
-  island_replicates[[1]] <- DAISIE:::DAISIE_sim_core_constant_rate(
+  island_replicates[[1]] <- DAISIE:::DAISIE_sim_core_cr(
     time = time,
     pars = pars,
     mainland_n = mainland_n,
@@ -148,8 +146,8 @@ test_that("DAISIE_format_IW prints when verbose = TRUE", {
     hyper_pars = hyper_pars,
     nonoceanic_pars = nonoceanic_pars
   )
-  expect_output(
-    formated_IW_sim <- DAISIE:::DAISIE_format_IW(
+  expect_message(
+    formatted_IW_sim <- DAISIE:::DAISIE_format_IW(
       island_replicates = island_replicates,
       time = time,
       M = mainland_n,
@@ -178,7 +176,7 @@ test_that("silent with empty nonoceanic island with correct output", {
   hyper_pars <- create_hyper_pars(d = 0, x = 0)
   set.seed(1)
   island_replicates <- list()
-  island_replicates[[1]] <- DAISIE:::DAISIE_sim_core_constant_rate(
+  island_replicates[[1]] <- DAISIE:::DAISIE_sim_core_cr(
     time = time,
     mainland_n = mainland_n,
     pars = pars,
@@ -187,7 +185,7 @@ test_that("silent with empty nonoceanic island with correct output", {
     nonoceanic_pars = nonoceanic_pars
   )
   expect_silent(
-    formated_IW_sim <- DAISIE:::DAISIE_format_IW(
+    formatted_IW_sim <- DAISIE:::DAISIE_format_IW(
       island_replicates = island_replicates,
       time = time,
       M = mainland_n,
@@ -201,14 +199,14 @@ test_that("silent with empty nonoceanic island with correct output", {
   colnames(stt_all) <- c("Time", "nI", "nA", "nC")
   stt_all[1, ] <- c(1, 1, 2, 0)
   stt_all[2, ] <- c(0, 0, 0, 0)
-  brts_table <- matrix(ncol = 4, nrow = 1)
-  colnames(brts_table) <- c("brt", "clade", "event", "endemic")
-  brts_table[1, ] <- c(1, 0, 0, NA)
+  brts_table <- matrix(ncol = 5, nrow = 1)
+  colnames(brts_table) <- c("brt", "clade", "event", "endemic", "col")
+  brts_table[1, ] <- c(1, 0, 0, NA, NA)
   expected_IW_format[[1]][[1]] <- list(island_age = 1,
                                        not_present = 10,
                                        stt_all = stt_all,
                                        brts_table = brts_table)
-  expect_equal(formated_IW_sim, expected_IW_format)
+  expect_equal(formatted_IW_sim, expected_IW_format)
 })
 
 test_that("silent with non-empty nonoceanic island with
@@ -231,7 +229,7 @@ test_that("silent with non-empty nonoceanic island with
 
             set.seed(1)
             island_replicates <- list()
-            island_replicates[[1]] <- DAISIE:::DAISIE_sim_core_constant_rate(
+            island_replicates[[1]] <- DAISIE:::DAISIE_sim_core_cr(
               time = time,
               mainland_n = mainland_n,
               pars = pars,
@@ -240,7 +238,7 @@ test_that("silent with non-empty nonoceanic island with
               hyper_pars = hyper_pars
             )
             expect_silent(
-              formated_IW_sim <- DAISIE:::DAISIE_format_IW(
+              formatted_IW_sim <- DAISIE:::DAISIE_format_IW(
                 island_replicates = island_replicates,
                 time = time,
                 M = mainland_n,
@@ -254,24 +252,22 @@ test_that("silent with non-empty nonoceanic island with
             colnames(stt_all) <- c("Time", "nI", "nA", "nC")
             stt_all[1, ] <- c(1, 1, 2, 0)
             stt_all[2, ] <- c(0, 0, 2, 0)
-            brts_table <- matrix(ncol = 4, nrow = 3)
-            colnames(brts_table) <- c("brt", "clade", "event", "endemic")
-            brts_table[1, ] <- c(1, 0, 0, NA)
-            brts_table[2, ] <- c(1, 2, 1, 1)
-            brts_table[3, ] <- c(1, 1, 1, 1)
+            brts_table <- matrix(ncol = 5, nrow = 3)
+            colnames(brts_table) <- c("brt", "clade", "event", "endemic", "col")
+            brts_table[1, ] <- c(1, 0, 0, NA, NA)
+            brts_table[2, ] <- c(1, 2, 1, 1, NA)
+            brts_table[3, ] <- c(1, 1, 1, 1, NA)
             expected_IW_format[[1]][[1]] <- list(island_age = 1,
                                                  not_present = 8,
                                                  stt_all = stt_all,
                                                  brts_table = brts_table)
-            expected_IW_format[[1]][[2]] <- list(branching_times = c(1,
-                                                                     1),
+            expected_IW_format[[1]][[2]] <- list(branching_times = c(1, 1),
                                                  stac = 2,
-                                       missing_species = 0)
-  expected_IW_format[[1]][[3]] <- list(branching_times = c(1,
-                                                           1),
-                                       stac = 2,
-                                       missing_species = 0)
-  expect_true(all.equal(formated_IW_sim, expected_IW_format, tolerance = 1e-7))
+                                                 missing_species = 0)
+            expected_IW_format[[1]][[3]] <- list(branching_times = c(1, 1),
+                                                 stac = 2,
+                                                 missing_species = 0)
+  expect_equal(formatted_IW_sim, expected_IW_format, tolerance = 1e-7)
 })
 
 test_that("silent with non-empty nonoceanic island with
@@ -294,7 +290,7 @@ test_that("silent with non-empty nonoceanic island with
 
             set.seed(1)
             island_replicates <- list()
-            island_replicates[[1]] <- DAISIE:::DAISIE_sim_core_constant_rate(
+            island_replicates[[1]] <- DAISIE:::DAISIE_sim_core_cr(
               time = time,
               mainland_n = mainland_n,
               pars = pars,
@@ -303,7 +299,7 @@ test_that("silent with non-empty nonoceanic island with
               hyper_pars = hyper_pars
             )
             expect_silent(
-              formated_IW_sim <- DAISIE:::DAISIE_format_IW(
+              formatted_IW_sim <- DAISIE:::DAISIE_format_IW(
                 island_replicates = island_replicates,
                 time = time,
                 M = mainland_n,
@@ -317,52 +313,50 @@ test_that("silent with non-empty nonoceanic island with
             colnames(stt_all) <- c("Time", "nI", "nA", "nC")
             stt_all[1, ] <- c(1, 1, 2, 0)
             stt_all[2, ] <- c(0, 0, 2, 0)
-            brts_table <- matrix(ncol = 4, nrow = 3)
-            colnames(brts_table) <- c("brt", "clade", "event", "endemic")
-            brts_table[1, ] <- c(1, 0, 0, NA)
-            brts_table[2, ] <- c(1, 2, 1, 1)
-            brts_table[3, ] <- c(1, 1, 1, 1)
+            brts_table <- matrix(ncol = 5, nrow = 3)
+            colnames(brts_table) <- c("brt", "clade", "event", "endemic", "col")
+            brts_table[1, ] <- c(1, 0, 0, NA, NA)
+            brts_table[2, ] <- c(1, 2, 1, 1, NA)
+            brts_table[3, ] <- c(1, 1, 1, 1, NA)
             expected_IW_format[[1]][[1]] <- list(island_age = 1,
                                                  not_present = 8,
                                                  stt_all = stt_all,
                                                  brts_table = brts_table)
-            expected_IW_format[[1]][[2]] <- list(branching_times = c(1,
-                                                                     1),
+            expected_IW_format[[1]][[2]] <- list(branching_times = c(1, 1),
                                                  stac = 2,
                                        missing_species = 0)
-  expected_IW_format[[1]][[3]] <- list(branching_times = c(1,
-                                                           1),
+  expected_IW_format[[1]][[3]] <- list(branching_times = c(1, 1),
                                        stac = 2,
                                        missing_species = 0)
-  expect_true(all.equal(formated_IW_sim, expected_IW_format, tolerance = 1e-7))
+  expect_equal(formatted_IW_sim, expected_IW_format, tolerance = 1e-7)
 })
 
-test_that("Add_brt_table output is correct when length(island) == 1", {
+test_that("add_brt_table output is correct when length(island) == 1", {
   stt_all <- matrix(ncol = 4, nrow = 2)
   colnames(stt_all) <- c("Time", "nI", "nA", "nC")
   stt_all[1, ] <- c(1, 0, 0, 0)
   stt_all[2, ] <- c(0, 0, 0, 0)
   island <- list()
   island[[1]] <- list(island_age = 1,
-                 not_present = 100,
-                 stt_all = stt_all,
-                 init_nonend_spec = 0,
-                 init_end_spec = 0)
-  formatted_brt <- DAISIE:::Add_brt_table(island)
-  brt_table <- matrix(ncol = 4, nrow = 1)
-  colnames(brt_table) <- c("brt", "clade", "event", "endemic")
-  brt_table[1, ] <- c(1, 0, 0, NA)
+                      not_present = 100,
+                      stt_all = stt_all,
+                      init_nonend_spec = 0,
+                      init_end_spec = 0)
+  formatted_brt <- DAISIE:::add_brt_table(island)
+  brt_table <- matrix(ncol = 5, nrow = 1)
+  colnames(brt_table) <- c("brt", "clade", "event", "endemic", "col")
+  brt_table[1, ] <- c(1, 0, 0, NA, NA)
   expected_brt <- list()
   expected_brt[[1]] <- list(island_age = 1,
-                        not_present = 100,
-                        stt_all = stt_all,
-                        init_nonend_spec = 0,
-                        init_end_spec = 0,
-                        brts_table = brt_table)
-  expect_true(all.equal(formatted_brt, expected_brt))
+                            not_present = 100,
+                            stt_all = stt_all,
+                            init_nonend_spec = 0,
+                            init_end_spec = 0,
+                            brts_table = brt_table)
+  expect_equal(formatted_brt, expected_brt)
 })
 
-test_that("Add_brt_table output is correct when length(island) != 1", {
+test_that("add_brt_table output is correct when length(island) != 1", {
   stt_all <- matrix(ncol = 4, nrow = 2)
   colnames(stt_all) <- c("Time", "nI", "nA", "nC")
   stt_all[1, ] <- c(1, 0, 0, 0)
@@ -387,43 +381,43 @@ test_that("Add_brt_table output is correct when length(island) != 1", {
                                          0.5288428),
                       stac = 4,
                       missing_species = 0)
-  formatted_brt <- DAISIE:::Add_brt_table(island)
-  brt_table <- matrix(ncol = 4, nrow = 5)
-  colnames(brt_table) <- c("brt", "clade", "event", "endemic")
-  brt_table[1, ] <- c(1, 0, 0, NA)
-  brt_table[2, ] <- c(0.9244818, 1, 1, 1)
-  brt_table[3, ] <- c(0.9105857, 1, 2, 1)
-  brt_table[4, ] <- c(0.5557734, 2, 1, 0)
-  brt_table[5, ] <- c(0.3146836, 1, 3, 1)
+  formatted_brt <- DAISIE:::add_brt_table(island)
+  brt_table <- matrix(ncol = 5, nrow = 5)
+  colnames(brt_table) <- c("brt", "clade", "event", "endemic", "col")
+  brt_table[1, ] <- c(1, 0, 0, NA, NA)
+  brt_table[2, ] <- c(0.9244818, 1, 1, 1, NA)
+  brt_table[3, ] <- c(0.9105857, 1, 2, 1, NA)
+  brt_table[4, ] <- c(0.5557734, 2, 1, 0, NA)
+  brt_table[5, ] <- c(0.3146836, 1, 3, 1, NA)
   expected_brt <- list()
   expected_brt[[1]] <- list(island_age = 1,
-                        not_present = 3,
-                        stt_all = stt_all,
-                        init_nonend_spec = 0,
-                        init_end_spec = 0,
-                        brts_table = brt_table)
+                            not_present = 3,
+                            stt_all = stt_all,
+                            init_nonend_spec = 0,
+                            init_end_spec = 0,
+                            brts_table = brt_table)
   expected_brt[[2]] <- list(branching_times = c(1.0000000,
-                                                 0.9244818,
-                                                 0.9105857,
-                                                 0.3146836),
-                             stac = 2,
-                             missing_species = 0)
+                                                0.9244818,
+                                                0.9105857,
+                                                0.3146836),
+                            stac = 2,
+                            missing_species = 0)
   expected_brt[[3]] <- list(branching_times = c(1.0000000,
-                                                 0.5557734),
-                             stac = 4,
-                             missing_species = 0)
+                                                0.5557734),
+                            stac = 4,
+                            missing_species = 0)
   expect_equal(formatted_brt, expected_brt)
 })
-#test_that("Add_brt_table output is correct when length(stac1_5s) != 0")
-#test_that("Add_brt_table output is correct when length(stac1_5s) == 0")
-#test_that("Add_brt_table output is correct when length(island_no_stac1or5) != 0")
+#test_that("add_brt_table output is correct when length(stac1_5s) != 0")
+#test_that("add_brt_table output is correct when length(stac1_5s) == 0")
+#test_that("add_brt_table output is correct when length(island_no_stac1or5) != 0")
 
 test_that("abuse", {
   expect_error(DAISIE:::DAISIE_format_IW("nonsense"))
 })
 
 test_that("abuse", {
-  expect_error(DAISIE:::Add_brt_table("nonsense"))
+  expect_error(DAISIE:::add_brt_table("nonsense"))
 })
 
 
@@ -446,7 +440,7 @@ test_that("silent with empty island with correct output", {
   start_midway <- FALSE
   set.seed(1)
   island_replicates <- list()
-  island_replicates[[1]] <- DAISIE:::DAISIE_sim_core_trait_dependent(
+  island_replicates[[1]] <- DAISIE:::DAISIE_sim_core_trait_dep(
     time = time,
     pars = pars,
     hyper_pars = create_hyper_pars(d = 0, x = 0),
@@ -462,7 +456,7 @@ test_that("silent with empty island with correct output", {
     mainland_n = mainland_n
   )
   expect_silent(
-    formated_IW_sim <- DAISIE:::DAISIE_format_IW(
+    formatted_IW_sim <- DAISIE:::DAISIE_format_IW(
       island_replicates = island_replicates,
       time = time,
       M = mainland_n,
@@ -477,40 +471,14 @@ test_that("silent with empty island with correct output", {
   colnames(stt_all) <- c("Time", "nI", "nA", "nC", "nI2", "nA2", "nC2")
   stt_all[1, ] <- c(1, 0, 0, 0, 0, 0, 0)
   stt_all[2, ] <- c(0, 0, 0, 0, 0, 0, 0)
-  brts_table <- matrix(ncol = 4, nrow = 1)
-  colnames(brts_table) <- c("brt", "clade", "event", "endemic")
-  brts_table[1, ] <- c(1, 0, 0, NA)
+  brts_table <- matrix(ncol = 5, nrow = 1)
+  colnames(brts_table) <- c("brt", "clade", "event", "endemic", "col")
+  brts_table[1, ] <- c(1, 0, 0, NA, NA)
   expected_IW_format[[1]][[1]] <- list(island_age = 1,
                                        not_present = 20,
                                        stt_all = stt_all,
                                        brts_table = brts_table)
-  expect_true(all.equal(formated_IW_sim, expected_IW_format, tolerance = 1e-7))
-})
-
-test_that("new and v1.5 give same results", {
-
-  tol <- 1e-13
-  sim_time <- 10
-  n_mainland_species <- 300
-  clado_rate <- 1.0
-  ext_rate <- 0.5
-  carr_cap <- 10
-  imm_rate <- 1.0
-  ana_rate <- 1.0
-  pars <- c(clado_rate, ext_rate, carr_cap, imm_rate, ana_rate)
-  rng_seed <- 42
-  set.seed(rng_seed)
-  ff <- DAISIE_sim(time = sim_time,
-                   M = n_mainland_species,
-                   pars = pars,
-                   replicates = 1,
-                   divdepmodel = 'IW')
-  ff[[1]][[1]]$brts_table <- 0
-  new <- DAISIE:::Add_brt_table(ff[[1]])
-  new <- new[[1]]$brts_table[-1,]
-  old <- DAISIE:::Add_brt_table_v1_5(ff[[1]])
-  old <- old[[1]]$brts_table[-1,]
-  testthat::expect_true(all(abs(new - old) < tol))
+  expect_equal(formatted_IW_sim, expected_IW_format, tolerance = 1e-7)
 })
 
 test_that("silent when species with two trait states with
@@ -518,7 +486,6 @@ test_that("silent when species with two trait states with
             pars <- c(0.4, 0.2, 10, 0.06, 0.5)
             time <- 5
             mainland_n <- 10
-            nonoceanic_pars <- c(0, 0)
             verbose <- FALSE
             replicates <- 3
             island_ontogeny = 0
@@ -536,11 +503,10 @@ test_that("silent when species with two trait states with
             island_replicates <- list()
             verbose <- FALSE
             set.seed(1)
-            island_replicates[[1]] <- DAISIE:::DAISIE_sim_core_trait_dependent(
+            island_replicates[[1]] <- DAISIE:::DAISIE_sim_core_trait_dep(
               time = time,
               mainland_n = mainland_n,
               pars = pars,
-              nonoceanic_pars = nonoceanic_pars,
               trait_pars = trait_pars,
               island_ontogeny = island_ontogeny,
               sea_level = sea_level,
@@ -556,7 +522,7 @@ test_that("silent when species with two trait states with
               extcutoff = extcutoff
             )
             expect_silent(
-              formated_IW_sim <- DAISIE:::DAISIE_format_IW(
+              formatted_IW_sim <- DAISIE:::DAISIE_format_IW(
                 island_replicates = island_replicates,
                 time = time,
                 M = mainland_n,
@@ -571,24 +537,29 @@ test_that("silent when species with two trait states with
             colnames(stt_all) <- c("Time", "nI", "nA", "nC", "nI2", "nA2", "nC2")
             stt_all[1, ] <- c(5, 0, 0, 0, 0, 0, 0)
             stt_all[2, ] <- c(0, 0, 1, 2, 0, 0, 0)
-            brts_table <- matrix(ncol = 4, nrow = 4)
-            colnames(brts_table) <- c("brt", "clade", "event", "endemic")
-            brts_table[1, ] <- c(5.000000000, 0, 0, NA)
-            brts_table[2, ] <- c(3.102613675, 1, 1, 1)
-            brts_table[3, ] <- c(1.505629998, 2, 1, 1)
-            brts_table[4, ] <- c(1.262456559, 2, 2, 1)
+            brts_table <- matrix(ncol = 5, nrow = 4)
+            colnames(brts_table) <- c("brt", "clade", "event", "endemic", "col")
+            brts_table[1, ] <- c(5.00000000000000, 0, 0, NA, NA)
+            brts_table[2, ] <- c(3.10634202528338, 1, 1, 1, NA)
+            brts_table[3, ] <- c(1.52330128016821, 2, 1, 1, NA)
+            brts_table[4, ] <- c(1.28012784155125, 2, 2, 1, NA)
             expected_IW_format[[1]][[1]] <- list(island_age = 5,
                                                  not_present = 13,
                                                  stt_all = stt_all,
                                                  brts_table = brts_table)
-            expected_IW_format[[1]][[2]] <- list(branching_times = c(5.000000000,
-                                                                     3.102613675),
-                                                 stac = 2,
-                                                 missing_species = 0)
-            expected_IW_format[[1]][[3]] <- list(branching_times = c(5.000000000,
-                                                                     1.505629998,
-                                                                     1.262456559),
-                                                 stac = 2,
-                                                 missing_species = 0)
-            expect_true(all.equal(formated_IW_sim, expected_IW_format, tolerance = 1e-7))
+
+            expected_IW_format[[1]][[2]] <- list(
+              branching_times = c(5.00000000000000,
+                                  3.10634202528338),
+              stac = 2,
+              missing_species = 0
+            )
+            expected_IW_format[[1]][[3]] <- list(
+              branching_times = c(5.00000000000000,
+                                  1.52330128016821,
+                                  1.28012784155125),
+              stac = 2,
+              missing_species = 0
+            )
+            expect_equal(formatted_IW_sim, expected_IW_format, tolerance = 1e-7)
           })
